# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.8.0] - 2024-08-23

### Added

- Initial open source release 
- Includes Exchange, Message, Tool, Moderator, and Provider
- Supported providers: Anthropic, Bedrock, Databricks, OpenAI
